from kii.stream import views

from . import models


class EntryList(views.List):
    streamitem_class = models.Entry

